@@ -1,25 +1,29 @@
 """
 Converter for `git diff` paths
 """
-from __future__ import unicode_literals
 import os
-import six
 import subprocess
 
 
 class GitPathTool(object):
     """
     Converts `git diff` paths to absolute paths or relative paths to cwd.
+    This class should be used throughout the project to change paths from
+    the paths yielded by `git diff` to correct project paths
     """
+    _cwd = None
+    _root = None
 
-    def __init__(self, cwd):
+    @classmethod
+    def set_cwd(cls, cwd):
         """
-        Initialize the absolute path to the git project
+        Set the cwd that is used to manipulate paths.
         """
-        self._cwd = cwd
-        self._root = self._git_root()
+        cls._cwd = cwd
+        cls._root = cls._git_root()
 
-    def relative_path(self, git_diff_path):
+    @classmethod
+    def relative_path(cls, git_diff_path):
         """
         Returns git_diff_path relative to cwd.
         """
@@ -27,24 +31,24 @@ class GitPathTool(object):
         # If cwd is `/home/user/work/diff-cover/diff_cover`
         # and src_path is `diff_cover/violations_reporter.py`
         # search for `violations_reporter.py`
-        root_rel_path = os.path.relpath(self._cwd, self._root)
-        if isinstance(root_rel_path, six.binary_type):
-            root_rel_path = root_rel_path.decode()
+        root_rel_path = os.path.relpath(cls._cwd, cls._root)
         rel_path = os.path.relpath(git_diff_path, root_rel_path)
-        if isinstance(rel_path, six.binary_type):
-            rel_path = rel_path.decode()
+
         return rel_path
 
-    def absolute_path(self, src_path):
+    @classmethod
+    def absolute_path(cls, src_path):
         """
         Returns absoloute git_diff_path
         """
         # If cwd is `/home/user/work/diff-cover/diff_cover`
         # and src_path is `other_package/some_file.py`
         # search for `/home/user/work/diff-cover/other_package/some_file.py`
-        return os.path.join(self._root, src_path)
 
-    def _git_root(self):
+        return os.path.join(cls._root, src_path)
+
+    @classmethod
+    def _git_root(cls):
         """
         Returns the output of `git rev-parse --show-toplevel`, which
         is the absolute path for the git project root.
